# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class AllowedAccess(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'acc_id': 'str',
        'access_rules_type': 'str',
        'allowed_api': 'bool',
        'alloweds_login': 'bool',
        'err_msg': 'str',
        'hash': 'str',
        'is_valid': 'bool',
        'name': 'str',
        'sub_claims': 'dict(str, list[str])'
    }

    attribute_map = {
        'acc_id': 'acc_id',
        'access_rules_type': 'access_rules_type',
        'allowed_api': 'allowed_api',
        'alloweds_login': 'alloweds_login',
        'err_msg': 'err_msg',
        'hash': 'hash',
        'is_valid': 'is_valid',
        'name': 'name',
        'sub_claims': 'sub_claims'
    }

    def __init__(self, acc_id=None, access_rules_type=None, allowed_api=None, alloweds_login=None, err_msg=None, hash=None, is_valid=None, name=None, sub_claims=None, local_vars_configuration=None):  # noqa: E501
        """AllowedAccess - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._acc_id = None
        self._access_rules_type = None
        self._allowed_api = None
        self._alloweds_login = None
        self._err_msg = None
        self._hash = None
        self._is_valid = None
        self._name = None
        self._sub_claims = None
        self.discriminator = None

        if acc_id is not None:
            self.acc_id = acc_id
        if access_rules_type is not None:
            self.access_rules_type = access_rules_type
        if allowed_api is not None:
            self.allowed_api = allowed_api
        if alloweds_login is not None:
            self.alloweds_login = alloweds_login
        if err_msg is not None:
            self.err_msg = err_msg
        if hash is not None:
            self.hash = hash
        if is_valid is not None:
            self.is_valid = is_valid
        if name is not None:
            self.name = name
        if sub_claims is not None:
            self.sub_claims = sub_claims

    @property
    def acc_id(self):
        """Gets the acc_id of this AllowedAccess.  # noqa: E501


        :return: The acc_id of this AllowedAccess.  # noqa: E501
        :rtype: str
        """
        return self._acc_id

    @acc_id.setter
    def acc_id(self, acc_id):
        """Sets the acc_id of this AllowedAccess.


        :param acc_id: The acc_id of this AllowedAccess.  # noqa: E501
        :type: str
        """

        self._acc_id = acc_id

    @property
    def access_rules_type(self):
        """Gets the access_rules_type of this AllowedAccess.  # noqa: E501


        :return: The access_rules_type of this AllowedAccess.  # noqa: E501
        :rtype: str
        """
        return self._access_rules_type

    @access_rules_type.setter
    def access_rules_type(self, access_rules_type):
        """Sets the access_rules_type of this AllowedAccess.


        :param access_rules_type: The access_rules_type of this AllowedAccess.  # noqa: E501
        :type: str
        """

        self._access_rules_type = access_rules_type

    @property
    def allowed_api(self):
        """Gets the allowed_api of this AllowedAccess.  # noqa: E501


        :return: The allowed_api of this AllowedAccess.  # noqa: E501
        :rtype: bool
        """
        return self._allowed_api

    @allowed_api.setter
    def allowed_api(self, allowed_api):
        """Sets the allowed_api of this AllowedAccess.


        :param allowed_api: The allowed_api of this AllowedAccess.  # noqa: E501
        :type: bool
        """

        self._allowed_api = allowed_api

    @property
    def alloweds_login(self):
        """Gets the alloweds_login of this AllowedAccess.  # noqa: E501


        :return: The alloweds_login of this AllowedAccess.  # noqa: E501
        :rtype: bool
        """
        return self._alloweds_login

    @alloweds_login.setter
    def alloweds_login(self, alloweds_login):
        """Sets the alloweds_login of this AllowedAccess.


        :param alloweds_login: The alloweds_login of this AllowedAccess.  # noqa: E501
        :type: bool
        """

        self._alloweds_login = alloweds_login

    @property
    def err_msg(self):
        """Gets the err_msg of this AllowedAccess.  # noqa: E501


        :return: The err_msg of this AllowedAccess.  # noqa: E501
        :rtype: str
        """
        return self._err_msg

    @err_msg.setter
    def err_msg(self, err_msg):
        """Sets the err_msg of this AllowedAccess.


        :param err_msg: The err_msg of this AllowedAccess.  # noqa: E501
        :type: str
        """

        self._err_msg = err_msg

    @property
    def hash(self):
        """Gets the hash of this AllowedAccess.  # noqa: E501


        :return: The hash of this AllowedAccess.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this AllowedAccess.


        :param hash: The hash of this AllowedAccess.  # noqa: E501
        :type: str
        """

        self._hash = hash

    @property
    def is_valid(self):
        """Gets the is_valid of this AllowedAccess.  # noqa: E501


        :return: The is_valid of this AllowedAccess.  # noqa: E501
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """Sets the is_valid of this AllowedAccess.


        :param is_valid: The is_valid of this AllowedAccess.  # noqa: E501
        :type: bool
        """

        self._is_valid = is_valid

    @property
    def name(self):
        """Gets the name of this AllowedAccess.  # noqa: E501


        :return: The name of this AllowedAccess.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AllowedAccess.


        :param name: The name of this AllowedAccess.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def sub_claims(self):
        """Gets the sub_claims of this AllowedAccess.  # noqa: E501


        :return: The sub_claims of this AllowedAccess.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._sub_claims

    @sub_claims.setter
    def sub_claims(self, sub_claims):
        """Sets the sub_claims of this AllowedAccess.


        :param sub_claims: The sub_claims of this AllowedAccess.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._sub_claims = sub_claims

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AllowedAccess):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AllowedAccess):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class PKICertificateIssueDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allow_any_name': 'bool',
        'allow_subdomains': 'bool',
        'allowed_domains_list': 'list[str]',
        'allowed_uri_sans': 'list[str]',
        'basic_constraints_valid_for_non_ca': 'bool',
        'client_flag': 'bool',
        'code_signing_flag': 'bool',
        'country': 'list[str]',
        'enforce_hostnames': 'bool',
        'is_ca': 'bool',
        'key_bits': 'int',
        'key_type': 'str',
        'key_usage_list': 'list[str]',
        'locality': 'list[str]',
        'not_before_duration': 'int',
        'organization_list': 'list[str]',
        'organization_unit_list': 'list[str]',
        'postal_code': 'list[str]',
        'province': 'list[str]',
        'require_cn': 'bool',
        'server_flag': 'bool',
        'street_address': 'list[str]'
    }

    attribute_map = {
        'allow_any_name': 'allow_any_name',
        'allow_subdomains': 'allow_subdomains',
        'allowed_domains_list': 'allowed_domains_list',
        'allowed_uri_sans': 'allowed_uri_sans',
        'basic_constraints_valid_for_non_ca': 'basic_constraints_valid_for_non_ca',
        'client_flag': 'client_flag',
        'code_signing_flag': 'code_signing_flag',
        'country': 'country',
        'enforce_hostnames': 'enforce_hostnames',
        'is_ca': 'is_ca',
        'key_bits': 'key_bits',
        'key_type': 'key_type',
        'key_usage_list': 'key_usage_list',
        'locality': 'locality',
        'not_before_duration': 'not_before_duration',
        'organization_list': 'organization_list',
        'organization_unit_list': 'organization_unit_list',
        'postal_code': 'postal_code',
        'province': 'province',
        'require_cn': 'require_cn',
        'server_flag': 'server_flag',
        'street_address': 'street_address'
    }

    def __init__(self, allow_any_name=None, allow_subdomains=None, allowed_domains_list=None, allowed_uri_sans=None, basic_constraints_valid_for_non_ca=None, client_flag=None, code_signing_flag=None, country=None, enforce_hostnames=None, is_ca=None, key_bits=None, key_type=None, key_usage_list=None, locality=None, not_before_duration=None, organization_list=None, organization_unit_list=None, postal_code=None, province=None, require_cn=None, server_flag=None, street_address=None, local_vars_configuration=None):  # noqa: E501
        """PKICertificateIssueDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._allow_any_name = None
        self._allow_subdomains = None
        self._allowed_domains_list = None
        self._allowed_uri_sans = None
        self._basic_constraints_valid_for_non_ca = None
        self._client_flag = None
        self._code_signing_flag = None
        self._country = None
        self._enforce_hostnames = None
        self._is_ca = None
        self._key_bits = None
        self._key_type = None
        self._key_usage_list = None
        self._locality = None
        self._not_before_duration = None
        self._organization_list = None
        self._organization_unit_list = None
        self._postal_code = None
        self._province = None
        self._require_cn = None
        self._server_flag = None
        self._street_address = None
        self.discriminator = None

        if allow_any_name is not None:
            self.allow_any_name = allow_any_name
        if allow_subdomains is not None:
            self.allow_subdomains = allow_subdomains
        if allowed_domains_list is not None:
            self.allowed_domains_list = allowed_domains_list
        if allowed_uri_sans is not None:
            self.allowed_uri_sans = allowed_uri_sans
        if basic_constraints_valid_for_non_ca is not None:
            self.basic_constraints_valid_for_non_ca = basic_constraints_valid_for_non_ca
        if client_flag is not None:
            self.client_flag = client_flag
        if code_signing_flag is not None:
            self.code_signing_flag = code_signing_flag
        if country is not None:
            self.country = country
        if enforce_hostnames is not None:
            self.enforce_hostnames = enforce_hostnames
        if is_ca is not None:
            self.is_ca = is_ca
        if key_bits is not None:
            self.key_bits = key_bits
        if key_type is not None:
            self.key_type = key_type
        if key_usage_list is not None:
            self.key_usage_list = key_usage_list
        if locality is not None:
            self.locality = locality
        if not_before_duration is not None:
            self.not_before_duration = not_before_duration
        if organization_list is not None:
            self.organization_list = organization_list
        if organization_unit_list is not None:
            self.organization_unit_list = organization_unit_list
        if postal_code is not None:
            self.postal_code = postal_code
        if province is not None:
            self.province = province
        if require_cn is not None:
            self.require_cn = require_cn
        if server_flag is not None:
            self.server_flag = server_flag
        if street_address is not None:
            self.street_address = street_address

    @property
    def allow_any_name(self):
        """Gets the allow_any_name of this PKICertificateIssueDetails.  # noqa: E501


        :return: The allow_any_name of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: bool
        """
        return self._allow_any_name

    @allow_any_name.setter
    def allow_any_name(self, allow_any_name):
        """Sets the allow_any_name of this PKICertificateIssueDetails.


        :param allow_any_name: The allow_any_name of this PKICertificateIssueDetails.  # noqa: E501
        :type: bool
        """

        self._allow_any_name = allow_any_name

    @property
    def allow_subdomains(self):
        """Gets the allow_subdomains of this PKICertificateIssueDetails.  # noqa: E501


        :return: The allow_subdomains of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: bool
        """
        return self._allow_subdomains

    @allow_subdomains.setter
    def allow_subdomains(self, allow_subdomains):
        """Sets the allow_subdomains of this PKICertificateIssueDetails.


        :param allow_subdomains: The allow_subdomains of this PKICertificateIssueDetails.  # noqa: E501
        :type: bool
        """

        self._allow_subdomains = allow_subdomains

    @property
    def allowed_domains_list(self):
        """Gets the allowed_domains_list of this PKICertificateIssueDetails.  # noqa: E501


        :return: The allowed_domains_list of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_domains_list

    @allowed_domains_list.setter
    def allowed_domains_list(self, allowed_domains_list):
        """Sets the allowed_domains_list of this PKICertificateIssueDetails.


        :param allowed_domains_list: The allowed_domains_list of this PKICertificateIssueDetails.  # noqa: E501
        :type: list[str]
        """

        self._allowed_domains_list = allowed_domains_list

    @property
    def allowed_uri_sans(self):
        """Gets the allowed_uri_sans of this PKICertificateIssueDetails.  # noqa: E501


        :return: The allowed_uri_sans of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_uri_sans

    @allowed_uri_sans.setter
    def allowed_uri_sans(self, allowed_uri_sans):
        """Sets the allowed_uri_sans of this PKICertificateIssueDetails.


        :param allowed_uri_sans: The allowed_uri_sans of this PKICertificateIssueDetails.  # noqa: E501
        :type: list[str]
        """

        self._allowed_uri_sans = allowed_uri_sans

    @property
    def basic_constraints_valid_for_non_ca(self):
        """Gets the basic_constraints_valid_for_non_ca of this PKICertificateIssueDetails.  # noqa: E501


        :return: The basic_constraints_valid_for_non_ca of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: bool
        """
        return self._basic_constraints_valid_for_non_ca

    @basic_constraints_valid_for_non_ca.setter
    def basic_constraints_valid_for_non_ca(self, basic_constraints_valid_for_non_ca):
        """Sets the basic_constraints_valid_for_non_ca of this PKICertificateIssueDetails.


        :param basic_constraints_valid_for_non_ca: The basic_constraints_valid_for_non_ca of this PKICertificateIssueDetails.  # noqa: E501
        :type: bool
        """

        self._basic_constraints_valid_for_non_ca = basic_constraints_valid_for_non_ca

    @property
    def client_flag(self):
        """Gets the client_flag of this PKICertificateIssueDetails.  # noqa: E501


        :return: The client_flag of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: bool
        """
        return self._client_flag

    @client_flag.setter
    def client_flag(self, client_flag):
        """Sets the client_flag of this PKICertificateIssueDetails.


        :param client_flag: The client_flag of this PKICertificateIssueDetails.  # noqa: E501
        :type: bool
        """

        self._client_flag = client_flag

    @property
    def code_signing_flag(self):
        """Gets the code_signing_flag of this PKICertificateIssueDetails.  # noqa: E501


        :return: The code_signing_flag of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: bool
        """
        return self._code_signing_flag

    @code_signing_flag.setter
    def code_signing_flag(self, code_signing_flag):
        """Sets the code_signing_flag of this PKICertificateIssueDetails.


        :param code_signing_flag: The code_signing_flag of this PKICertificateIssueDetails.  # noqa: E501
        :type: bool
        """

        self._code_signing_flag = code_signing_flag

    @property
    def country(self):
        """Gets the country of this PKICertificateIssueDetails.  # noqa: E501


        :return: The country of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this PKICertificateIssueDetails.


        :param country: The country of this PKICertificateIssueDetails.  # noqa: E501
        :type: list[str]
        """

        self._country = country

    @property
    def enforce_hostnames(self):
        """Gets the enforce_hostnames of this PKICertificateIssueDetails.  # noqa: E501


        :return: The enforce_hostnames of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: bool
        """
        return self._enforce_hostnames

    @enforce_hostnames.setter
    def enforce_hostnames(self, enforce_hostnames):
        """Sets the enforce_hostnames of this PKICertificateIssueDetails.


        :param enforce_hostnames: The enforce_hostnames of this PKICertificateIssueDetails.  # noqa: E501
        :type: bool
        """

        self._enforce_hostnames = enforce_hostnames

    @property
    def is_ca(self):
        """Gets the is_ca of this PKICertificateIssueDetails.  # noqa: E501


        :return: The is_ca of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: bool
        """
        return self._is_ca

    @is_ca.setter
    def is_ca(self, is_ca):
        """Sets the is_ca of this PKICertificateIssueDetails.


        :param is_ca: The is_ca of this PKICertificateIssueDetails.  # noqa: E501
        :type: bool
        """

        self._is_ca = is_ca

    @property
    def key_bits(self):
        """Gets the key_bits of this PKICertificateIssueDetails.  # noqa: E501


        :return: The key_bits of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: int
        """
        return self._key_bits

    @key_bits.setter
    def key_bits(self, key_bits):
        """Sets the key_bits of this PKICertificateIssueDetails.


        :param key_bits: The key_bits of this PKICertificateIssueDetails.  # noqa: E501
        :type: int
        """

        self._key_bits = key_bits

    @property
    def key_type(self):
        """Gets the key_type of this PKICertificateIssueDetails.  # noqa: E501


        :return: The key_type of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: str
        """
        return self._key_type

    @key_type.setter
    def key_type(self, key_type):
        """Sets the key_type of this PKICertificateIssueDetails.


        :param key_type: The key_type of this PKICertificateIssueDetails.  # noqa: E501
        :type: str
        """

        self._key_type = key_type

    @property
    def key_usage_list(self):
        """Gets the key_usage_list of this PKICertificateIssueDetails.  # noqa: E501


        :return: The key_usage_list of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._key_usage_list

    @key_usage_list.setter
    def key_usage_list(self, key_usage_list):
        """Sets the key_usage_list of this PKICertificateIssueDetails.


        :param key_usage_list: The key_usage_list of this PKICertificateIssueDetails.  # noqa: E501
        :type: list[str]
        """

        self._key_usage_list = key_usage_list

    @property
    def locality(self):
        """Gets the locality of this PKICertificateIssueDetails.  # noqa: E501


        :return: The locality of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """Sets the locality of this PKICertificateIssueDetails.


        :param locality: The locality of this PKICertificateIssueDetails.  # noqa: E501
        :type: list[str]
        """

        self._locality = locality

    @property
    def not_before_duration(self):
        """Gets the not_before_duration of this PKICertificateIssueDetails.  # noqa: E501

        A Duration represents the elapsed time between two instants as an int64 nanosecond count. The representation limits the largest representable duration to approximately 290 years.  # noqa: E501

        :return: The not_before_duration of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: int
        """
        return self._not_before_duration

    @not_before_duration.setter
    def not_before_duration(self, not_before_duration):
        """Sets the not_before_duration of this PKICertificateIssueDetails.

        A Duration represents the elapsed time between two instants as an int64 nanosecond count. The representation limits the largest representable duration to approximately 290 years.  # noqa: E501

        :param not_before_duration: The not_before_duration of this PKICertificateIssueDetails.  # noqa: E501
        :type: int
        """

        self._not_before_duration = not_before_duration

    @property
    def organization_list(self):
        """Gets the organization_list of this PKICertificateIssueDetails.  # noqa: E501


        :return: The organization_list of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._organization_list

    @organization_list.setter
    def organization_list(self, organization_list):
        """Sets the organization_list of this PKICertificateIssueDetails.


        :param organization_list: The organization_list of this PKICertificateIssueDetails.  # noqa: E501
        :type: list[str]
        """

        self._organization_list = organization_list

    @property
    def organization_unit_list(self):
        """Gets the organization_unit_list of this PKICertificateIssueDetails.  # noqa: E501


        :return: The organization_unit_list of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._organization_unit_list

    @organization_unit_list.setter
    def organization_unit_list(self, organization_unit_list):
        """Sets the organization_unit_list of this PKICertificateIssueDetails.


        :param organization_unit_list: The organization_unit_list of this PKICertificateIssueDetails.  # noqa: E501
        :type: list[str]
        """

        self._organization_unit_list = organization_unit_list

    @property
    def postal_code(self):
        """Gets the postal_code of this PKICertificateIssueDetails.  # noqa: E501


        :return: The postal_code of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this PKICertificateIssueDetails.


        :param postal_code: The postal_code of this PKICertificateIssueDetails.  # noqa: E501
        :type: list[str]
        """

        self._postal_code = postal_code

    @property
    def province(self):
        """Gets the province of this PKICertificateIssueDetails.  # noqa: E501


        :return: The province of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._province

    @province.setter
    def province(self, province):
        """Sets the province of this PKICertificateIssueDetails.


        :param province: The province of this PKICertificateIssueDetails.  # noqa: E501
        :type: list[str]
        """

        self._province = province

    @property
    def require_cn(self):
        """Gets the require_cn of this PKICertificateIssueDetails.  # noqa: E501


        :return: The require_cn of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: bool
        """
        return self._require_cn

    @require_cn.setter
    def require_cn(self, require_cn):
        """Sets the require_cn of this PKICertificateIssueDetails.


        :param require_cn: The require_cn of this PKICertificateIssueDetails.  # noqa: E501
        :type: bool
        """

        self._require_cn = require_cn

    @property
    def server_flag(self):
        """Gets the server_flag of this PKICertificateIssueDetails.  # noqa: E501


        :return: The server_flag of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: bool
        """
        return self._server_flag

    @server_flag.setter
    def server_flag(self, server_flag):
        """Sets the server_flag of this PKICertificateIssueDetails.


        :param server_flag: The server_flag of this PKICertificateIssueDetails.  # noqa: E501
        :type: bool
        """

        self._server_flag = server_flag

    @property
    def street_address(self):
        """Gets the street_address of this PKICertificateIssueDetails.  # noqa: E501


        :return: The street_address of this PKICertificateIssueDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._street_address

    @street_address.setter
    def street_address(self, street_address):
        """Sets the street_address of this PKICertificateIssueDetails.


        :param street_address: The street_address of this PKICertificateIssueDetails.  # noqa: E501
        :type: list[str]
        """

        self._street_address = street_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PKICertificateIssueDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PKICertificateIssueDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.list_roles_output import ListRolesOutput  # noqa: E501
from akeyless.rest import ApiException

class TestListRolesOutput(unittest.TestCase):
    """ListRolesOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListRolesOutput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.list_roles_output.ListRolesOutput()  # noqa: E501
        if include_optional :
            return ListRolesOutput(
                next_page = '0', 
                roles = [
                    akeyless.models.role_includes_role_details/.Role includes role details.(
                        client_permissions = [
                            '0'
                            ], 
                        comment = '0', 
                        role_auth_methods_assoc = [
                            akeyless.models.role_auth_method_association.RoleAuthMethodAssociation(
                                assoc_id = '0', 
                                auth_method_access_id = '0', 
                                auth_method_name = '0', 
                                auth_method_sub_claims = {
                                    'key' : [
                                        '0'
                                        ]
                                    }, )
                            ], 
                        role_name = '0', 
                        rules = akeyless.models.rules_are_a_part_of_akeyless_rbac/.Rules are a part of AKEYLESS RBAC.(
                            admin = True, 
                            path_rules = [
                                akeyless.models.path_rule_is_a_single_rule_used_in_akeyless_rbac/.PathRule is a single rule used in AKEYLESS RBAC.(
                                    capabilities = [
                                        '0'
                                        ], 
                                    path = '0', 
                                    type = '0', )
                                ], ), )
                    ]
            )
        else :
            return ListRolesOutput(
        )

    def testListRolesOutput(self):
        """Test ListRolesOutput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class SystemAccessCredentialsReplyObj(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'auth_creds': 'str',
        'expiry': 'int',
        'kfm_creds': 'str',
        'token': 'str',
        'uam_creds': 'str'
    }

    attribute_map = {
        'auth_creds': 'auth_creds',
        'expiry': 'expiry',
        'kfm_creds': 'kfm_creds',
        'token': 'token',
        'uam_creds': 'uam_creds'
    }

    def __init__(self, auth_creds=None, expiry=None, kfm_creds=None, token=None, uam_creds=None, local_vars_configuration=None):  # noqa: E501
        """SystemAccessCredentialsReplyObj - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._auth_creds = None
        self._expiry = None
        self._kfm_creds = None
        self._token = None
        self._uam_creds = None
        self.discriminator = None

        if auth_creds is not None:
            self.auth_creds = auth_creds
        if expiry is not None:
            self.expiry = expiry
        if kfm_creds is not None:
            self.kfm_creds = kfm_creds
        if token is not None:
            self.token = token
        if uam_creds is not None:
            self.uam_creds = uam_creds

    @property
    def auth_creds(self):
        """Gets the auth_creds of this SystemAccessCredentialsReplyObj.  # noqa: E501

        Temporary credentials for accessing Auth  # noqa: E501

        :return: The auth_creds of this SystemAccessCredentialsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._auth_creds

    @auth_creds.setter
    def auth_creds(self, auth_creds):
        """Sets the auth_creds of this SystemAccessCredentialsReplyObj.

        Temporary credentials for accessing Auth  # noqa: E501

        :param auth_creds: The auth_creds of this SystemAccessCredentialsReplyObj.  # noqa: E501
        :type: str
        """

        self._auth_creds = auth_creds

    @property
    def expiry(self):
        """Gets the expiry of this SystemAccessCredentialsReplyObj.  # noqa: E501

        Credentials expiration date  # noqa: E501

        :return: The expiry of this SystemAccessCredentialsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._expiry

    @expiry.setter
    def expiry(self, expiry):
        """Sets the expiry of this SystemAccessCredentialsReplyObj.

        Credentials expiration date  # noqa: E501

        :param expiry: The expiry of this SystemAccessCredentialsReplyObj.  # noqa: E501
        :type: int
        """

        self._expiry = expiry

    @property
    def kfm_creds(self):
        """Gets the kfm_creds of this SystemAccessCredentialsReplyObj.  # noqa: E501

        Temporary credentials for accessing the KFMs instances  # noqa: E501

        :return: The kfm_creds of this SystemAccessCredentialsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._kfm_creds

    @kfm_creds.setter
    def kfm_creds(self, kfm_creds):
        """Sets the kfm_creds of this SystemAccessCredentialsReplyObj.

        Temporary credentials for accessing the KFMs instances  # noqa: E501

        :param kfm_creds: The kfm_creds of this SystemAccessCredentialsReplyObj.  # noqa: E501
        :type: str
        """

        self._kfm_creds = kfm_creds

    @property
    def token(self):
        """Gets the token of this SystemAccessCredentialsReplyObj.  # noqa: E501

        Credentials tmp token  # noqa: E501

        :return: The token of this SystemAccessCredentialsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this SystemAccessCredentialsReplyObj.

        Credentials tmp token  # noqa: E501

        :param token: The token of this SystemAccessCredentialsReplyObj.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uam_creds(self):
        """Gets the uam_creds of this SystemAccessCredentialsReplyObj.  # noqa: E501

        Temporary credentials for accessing the UAM service  # noqa: E501

        :return: The uam_creds of this SystemAccessCredentialsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._uam_creds

    @uam_creds.setter
    def uam_creds(self, uam_creds):
        """Sets the uam_creds of this SystemAccessCredentialsReplyObj.

        Temporary credentials for accessing the UAM service  # noqa: E501

        :param uam_creds: The uam_creds of this SystemAccessCredentialsReplyObj.  # noqa: E501
        :type: str
        """

        self._uam_creds = uam_creds

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemAccessCredentialsReplyObj):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SystemAccessCredentialsReplyObj):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class LogForwardingConfigPart(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'aws_s3_config': 'AwsS3LogForwardingConfig',
        'azure_analytics_config': 'AzureLogAnalyticsForwardingConfig',
        'datadog_config': 'DatadogForwardingConfig',
        'elasticsearch_config': 'ElasticsearchLogForwardingConfig',
        'json_output': 'bool',
        'logan_enable': 'bool',
        'logan_url': 'str',
        'logstash_config': 'LogstashLogForwardingConfig',
        'logz_io_config': 'LogzIoLogForwardingConfig',
        'pull_interval_sec': 'str',
        'splunk_config': 'SplunkLogForwardingConfig',
        'syslog_config': 'SyslogLogForwardingConfig',
        'target_log_type': 'str'
    }

    attribute_map = {
        'aws_s3_config': 'aws_s3_config',
        'azure_analytics_config': 'azure_analytics_config',
        'datadog_config': 'datadog_config',
        'elasticsearch_config': 'elasticsearch_config',
        'json_output': 'json_output',
        'logan_enable': 'logan_enable',
        'logan_url': 'logan_url',
        'logstash_config': 'logstash_config',
        'logz_io_config': 'logz_io_config',
        'pull_interval_sec': 'pull_interval_sec',
        'splunk_config': 'splunk_config',
        'syslog_config': 'syslog_config',
        'target_log_type': 'target_log_type'
    }

    def __init__(self, aws_s3_config=None, azure_analytics_config=None, datadog_config=None, elasticsearch_config=None, json_output=None, logan_enable=None, logan_url=None, logstash_config=None, logz_io_config=None, pull_interval_sec=None, splunk_config=None, syslog_config=None, target_log_type=None, local_vars_configuration=None):  # noqa: E501
        """LogForwardingConfigPart - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._aws_s3_config = None
        self._azure_analytics_config = None
        self._datadog_config = None
        self._elasticsearch_config = None
        self._json_output = None
        self._logan_enable = None
        self._logan_url = None
        self._logstash_config = None
        self._logz_io_config = None
        self._pull_interval_sec = None
        self._splunk_config = None
        self._syslog_config = None
        self._target_log_type = None
        self.discriminator = None

        if aws_s3_config is not None:
            self.aws_s3_config = aws_s3_config
        if azure_analytics_config is not None:
            self.azure_analytics_config = azure_analytics_config
        if datadog_config is not None:
            self.datadog_config = datadog_config
        if elasticsearch_config is not None:
            self.elasticsearch_config = elasticsearch_config
        if json_output is not None:
            self.json_output = json_output
        if logan_enable is not None:
            self.logan_enable = logan_enable
        if logan_url is not None:
            self.logan_url = logan_url
        if logstash_config is not None:
            self.logstash_config = logstash_config
        if logz_io_config is not None:
            self.logz_io_config = logz_io_config
        if pull_interval_sec is not None:
            self.pull_interval_sec = pull_interval_sec
        if splunk_config is not None:
            self.splunk_config = splunk_config
        if syslog_config is not None:
            self.syslog_config = syslog_config
        if target_log_type is not None:
            self.target_log_type = target_log_type

    @property
    def aws_s3_config(self):
        """Gets the aws_s3_config of this LogForwardingConfigPart.  # noqa: E501


        :return: The aws_s3_config of this LogForwardingConfigPart.  # noqa: E501
        :rtype: AwsS3LogForwardingConfig
        """
        return self._aws_s3_config

    @aws_s3_config.setter
    def aws_s3_config(self, aws_s3_config):
        """Sets the aws_s3_config of this LogForwardingConfigPart.


        :param aws_s3_config: The aws_s3_config of this LogForwardingConfigPart.  # noqa: E501
        :type: AwsS3LogForwardingConfig
        """

        self._aws_s3_config = aws_s3_config

    @property
    def azure_analytics_config(self):
        """Gets the azure_analytics_config of this LogForwardingConfigPart.  # noqa: E501


        :return: The azure_analytics_config of this LogForwardingConfigPart.  # noqa: E501
        :rtype: AzureLogAnalyticsForwardingConfig
        """
        return self._azure_analytics_config

    @azure_analytics_config.setter
    def azure_analytics_config(self, azure_analytics_config):
        """Sets the azure_analytics_config of this LogForwardingConfigPart.


        :param azure_analytics_config: The azure_analytics_config of this LogForwardingConfigPart.  # noqa: E501
        :type: AzureLogAnalyticsForwardingConfig
        """

        self._azure_analytics_config = azure_analytics_config

    @property
    def datadog_config(self):
        """Gets the datadog_config of this LogForwardingConfigPart.  # noqa: E501


        :return: The datadog_config of this LogForwardingConfigPart.  # noqa: E501
        :rtype: DatadogForwardingConfig
        """
        return self._datadog_config

    @datadog_config.setter
    def datadog_config(self, datadog_config):
        """Sets the datadog_config of this LogForwardingConfigPart.


        :param datadog_config: The datadog_config of this LogForwardingConfigPart.  # noqa: E501
        :type: DatadogForwardingConfig
        """

        self._datadog_config = datadog_config

    @property
    def elasticsearch_config(self):
        """Gets the elasticsearch_config of this LogForwardingConfigPart.  # noqa: E501


        :return: The elasticsearch_config of this LogForwardingConfigPart.  # noqa: E501
        :rtype: ElasticsearchLogForwardingConfig
        """
        return self._elasticsearch_config

    @elasticsearch_config.setter
    def elasticsearch_config(self, elasticsearch_config):
        """Sets the elasticsearch_config of this LogForwardingConfigPart.


        :param elasticsearch_config: The elasticsearch_config of this LogForwardingConfigPart.  # noqa: E501
        :type: ElasticsearchLogForwardingConfig
        """

        self._elasticsearch_config = elasticsearch_config

    @property
    def json_output(self):
        """Gets the json_output of this LogForwardingConfigPart.  # noqa: E501


        :return: The json_output of this LogForwardingConfigPart.  # noqa: E501
        :rtype: bool
        """
        return self._json_output

    @json_output.setter
    def json_output(self, json_output):
        """Sets the json_output of this LogForwardingConfigPart.


        :param json_output: The json_output of this LogForwardingConfigPart.  # noqa: E501
        :type: bool
        """

        self._json_output = json_output

    @property
    def logan_enable(self):
        """Gets the logan_enable of this LogForwardingConfigPart.  # noqa: E501


        :return: The logan_enable of this LogForwardingConfigPart.  # noqa: E501
        :rtype: bool
        """
        return self._logan_enable

    @logan_enable.setter
    def logan_enable(self, logan_enable):
        """Sets the logan_enable of this LogForwardingConfigPart.


        :param logan_enable: The logan_enable of this LogForwardingConfigPart.  # noqa: E501
        :type: bool
        """

        self._logan_enable = logan_enable

    @property
    def logan_url(self):
        """Gets the logan_url of this LogForwardingConfigPart.  # noqa: E501


        :return: The logan_url of this LogForwardingConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._logan_url

    @logan_url.setter
    def logan_url(self, logan_url):
        """Sets the logan_url of this LogForwardingConfigPart.


        :param logan_url: The logan_url of this LogForwardingConfigPart.  # noqa: E501
        :type: str
        """

        self._logan_url = logan_url

    @property
    def logstash_config(self):
        """Gets the logstash_config of this LogForwardingConfigPart.  # noqa: E501


        :return: The logstash_config of this LogForwardingConfigPart.  # noqa: E501
        :rtype: LogstashLogForwardingConfig
        """
        return self._logstash_config

    @logstash_config.setter
    def logstash_config(self, logstash_config):
        """Sets the logstash_config of this LogForwardingConfigPart.


        :param logstash_config: The logstash_config of this LogForwardingConfigPart.  # noqa: E501
        :type: LogstashLogForwardingConfig
        """

        self._logstash_config = logstash_config

    @property
    def logz_io_config(self):
        """Gets the logz_io_config of this LogForwardingConfigPart.  # noqa: E501


        :return: The logz_io_config of this LogForwardingConfigPart.  # noqa: E501
        :rtype: LogzIoLogForwardingConfig
        """
        return self._logz_io_config

    @logz_io_config.setter
    def logz_io_config(self, logz_io_config):
        """Sets the logz_io_config of this LogForwardingConfigPart.


        :param logz_io_config: The logz_io_config of this LogForwardingConfigPart.  # noqa: E501
        :type: LogzIoLogForwardingConfig
        """

        self._logz_io_config = logz_io_config

    @property
    def pull_interval_sec(self):
        """Gets the pull_interval_sec of this LogForwardingConfigPart.  # noqa: E501


        :return: The pull_interval_sec of this LogForwardingConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._pull_interval_sec

    @pull_interval_sec.setter
    def pull_interval_sec(self, pull_interval_sec):
        """Sets the pull_interval_sec of this LogForwardingConfigPart.


        :param pull_interval_sec: The pull_interval_sec of this LogForwardingConfigPart.  # noqa: E501
        :type: str
        """

        self._pull_interval_sec = pull_interval_sec

    @property
    def splunk_config(self):
        """Gets the splunk_config of this LogForwardingConfigPart.  # noqa: E501


        :return: The splunk_config of this LogForwardingConfigPart.  # noqa: E501
        :rtype: SplunkLogForwardingConfig
        """
        return self._splunk_config

    @splunk_config.setter
    def splunk_config(self, splunk_config):
        """Sets the splunk_config of this LogForwardingConfigPart.


        :param splunk_config: The splunk_config of this LogForwardingConfigPart.  # noqa: E501
        :type: SplunkLogForwardingConfig
        """

        self._splunk_config = splunk_config

    @property
    def syslog_config(self):
        """Gets the syslog_config of this LogForwardingConfigPart.  # noqa: E501


        :return: The syslog_config of this LogForwardingConfigPart.  # noqa: E501
        :rtype: SyslogLogForwardingConfig
        """
        return self._syslog_config

    @syslog_config.setter
    def syslog_config(self, syslog_config):
        """Sets the syslog_config of this LogForwardingConfigPart.


        :param syslog_config: The syslog_config of this LogForwardingConfigPart.  # noqa: E501
        :type: SyslogLogForwardingConfig
        """

        self._syslog_config = syslog_config

    @property
    def target_log_type(self):
        """Gets the target_log_type of this LogForwardingConfigPart.  # noqa: E501


        :return: The target_log_type of this LogForwardingConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._target_log_type

    @target_log_type.setter
    def target_log_type(self, target_log_type):
        """Sets the target_log_type of this LogForwardingConfigPart.


        :param target_log_type: The target_log_type of this LogForwardingConfigPart.  # noqa: E501
        :type: str
        """

        self._target_log_type = target_log_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LogForwardingConfigPart):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LogForwardingConfigPart):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayUpdateProducerGke(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'delete_protection': 'str',
        'gke_account_key': 'str',
        'gke_cluster_cert': 'str',
        'gke_cluster_endpoint': 'str',
        'gke_cluster_name': 'str',
        'gke_service_account_email': 'str',
        'json': 'bool',
        'name': 'str',
        'new_name': 'str',
        'producer_encryption_key_name': 'str',
        'secure_access_allow_port_forwading': 'bool',
        'secure_access_bastion_issuer': 'str',
        'secure_access_cluster_endpoint': 'str',
        'secure_access_enable': 'str',
        'secure_access_web': 'bool',
        'tags': 'list[str]',
        'target_name': 'str',
        'token': 'str',
        'uid_token': 'str',
        'user_ttl': 'str'
    }

    attribute_map = {
        'delete_protection': 'delete_protection',
        'gke_account_key': 'gke-account-key',
        'gke_cluster_cert': 'gke-cluster-cert',
        'gke_cluster_endpoint': 'gke-cluster-endpoint',
        'gke_cluster_name': 'gke-cluster-name',
        'gke_service_account_email': 'gke-service-account-email',
        'json': 'json',
        'name': 'name',
        'new_name': 'new-name',
        'producer_encryption_key_name': 'producer-encryption-key-name',
        'secure_access_allow_port_forwading': 'secure-access-allow-port-forwading',
        'secure_access_bastion_issuer': 'secure-access-bastion-issuer',
        'secure_access_cluster_endpoint': 'secure-access-cluster-endpoint',
        'secure_access_enable': 'secure-access-enable',
        'secure_access_web': 'secure-access-web',
        'tags': 'tags',
        'target_name': 'target-name',
        'token': 'token',
        'uid_token': 'uid-token',
        'user_ttl': 'user-ttl'
    }

    def __init__(self, delete_protection=None, gke_account_key=None, gke_cluster_cert=None, gke_cluster_endpoint=None, gke_cluster_name=None, gke_service_account_email=None, json=None, name=None, new_name=None, producer_encryption_key_name=None, secure_access_allow_port_forwading=None, secure_access_bastion_issuer=None, secure_access_cluster_endpoint=None, secure_access_enable=None, secure_access_web=None, tags=None, target_name=None, token=None, uid_token=None, user_ttl='60m', local_vars_configuration=None):  # noqa: E501
        """GatewayUpdateProducerGke - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._delete_protection = None
        self._gke_account_key = None
        self._gke_cluster_cert = None
        self._gke_cluster_endpoint = None
        self._gke_cluster_name = None
        self._gke_service_account_email = None
        self._json = None
        self._name = None
        self._new_name = None
        self._producer_encryption_key_name = None
        self._secure_access_allow_port_forwading = None
        self._secure_access_bastion_issuer = None
        self._secure_access_cluster_endpoint = None
        self._secure_access_enable = None
        self._secure_access_web = None
        self._tags = None
        self._target_name = None
        self._token = None
        self._uid_token = None
        self._user_ttl = None
        self.discriminator = None

        if delete_protection is not None:
            self.delete_protection = delete_protection
        if gke_account_key is not None:
            self.gke_account_key = gke_account_key
        if gke_cluster_cert is not None:
            self.gke_cluster_cert = gke_cluster_cert
        if gke_cluster_endpoint is not None:
            self.gke_cluster_endpoint = gke_cluster_endpoint
        if gke_cluster_name is not None:
            self.gke_cluster_name = gke_cluster_name
        if gke_service_account_email is not None:
            self.gke_service_account_email = gke_service_account_email
        if json is not None:
            self.json = json
        self.name = name
        if new_name is not None:
            self.new_name = new_name
        if producer_encryption_key_name is not None:
            self.producer_encryption_key_name = producer_encryption_key_name
        if secure_access_allow_port_forwading is not None:
            self.secure_access_allow_port_forwading = secure_access_allow_port_forwading
        if secure_access_bastion_issuer is not None:
            self.secure_access_bastion_issuer = secure_access_bastion_issuer
        if secure_access_cluster_endpoint is not None:
            self.secure_access_cluster_endpoint = secure_access_cluster_endpoint
        if secure_access_enable is not None:
            self.secure_access_enable = secure_access_enable
        if secure_access_web is not None:
            self.secure_access_web = secure_access_web
        if tags is not None:
            self.tags = tags
        if target_name is not None:
            self.target_name = target_name
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if user_ttl is not None:
            self.user_ttl = user_ttl

    @property
    def delete_protection(self):
        """Gets the delete_protection of this GatewayUpdateProducerGke.  # noqa: E501

        Protection from accidental deletion of this item  # noqa: E501

        :return: The delete_protection of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this GatewayUpdateProducerGke.

        Protection from accidental deletion of this item  # noqa: E501

        :param delete_protection: The delete_protection of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """

        self._delete_protection = delete_protection

    @property
    def gke_account_key(self):
        """Gets the gke_account_key of this GatewayUpdateProducerGke.  # noqa: E501

        GKE Service Account key file path  # noqa: E501

        :return: The gke_account_key of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._gke_account_key

    @gke_account_key.setter
    def gke_account_key(self, gke_account_key):
        """Sets the gke_account_key of this GatewayUpdateProducerGke.

        GKE Service Account key file path  # noqa: E501

        :param gke_account_key: The gke_account_key of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """

        self._gke_account_key = gke_account_key

    @property
    def gke_cluster_cert(self):
        """Gets the gke_cluster_cert of this GatewayUpdateProducerGke.  # noqa: E501

        GKE cluster CA certificate  # noqa: E501

        :return: The gke_cluster_cert of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._gke_cluster_cert

    @gke_cluster_cert.setter
    def gke_cluster_cert(self, gke_cluster_cert):
        """Sets the gke_cluster_cert of this GatewayUpdateProducerGke.

        GKE cluster CA certificate  # noqa: E501

        :param gke_cluster_cert: The gke_cluster_cert of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """

        self._gke_cluster_cert = gke_cluster_cert

    @property
    def gke_cluster_endpoint(self):
        """Gets the gke_cluster_endpoint of this GatewayUpdateProducerGke.  # noqa: E501

        GKE cluster URL endpoint  # noqa: E501

        :return: The gke_cluster_endpoint of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._gke_cluster_endpoint

    @gke_cluster_endpoint.setter
    def gke_cluster_endpoint(self, gke_cluster_endpoint):
        """Sets the gke_cluster_endpoint of this GatewayUpdateProducerGke.

        GKE cluster URL endpoint  # noqa: E501

        :param gke_cluster_endpoint: The gke_cluster_endpoint of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """

        self._gke_cluster_endpoint = gke_cluster_endpoint

    @property
    def gke_cluster_name(self):
        """Gets the gke_cluster_name of this GatewayUpdateProducerGke.  # noqa: E501

        GKE cluster name  # noqa: E501

        :return: The gke_cluster_name of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._gke_cluster_name

    @gke_cluster_name.setter
    def gke_cluster_name(self, gke_cluster_name):
        """Sets the gke_cluster_name of this GatewayUpdateProducerGke.

        GKE cluster name  # noqa: E501

        :param gke_cluster_name: The gke_cluster_name of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """

        self._gke_cluster_name = gke_cluster_name

    @property
    def gke_service_account_email(self):
        """Gets the gke_service_account_email of this GatewayUpdateProducerGke.  # noqa: E501

        GKE service account email  # noqa: E501

        :return: The gke_service_account_email of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._gke_service_account_email

    @gke_service_account_email.setter
    def gke_service_account_email(self, gke_service_account_email):
        """Sets the gke_service_account_email of this GatewayUpdateProducerGke.

        GKE service account email  # noqa: E501

        :param gke_service_account_email: The gke_service_account_email of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """

        self._gke_service_account_email = gke_service_account_email

    @property
    def json(self):
        """Gets the json of this GatewayUpdateProducerGke.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GatewayUpdateProducerGke.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GatewayUpdateProducerGke.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def name(self):
        """Gets the name of this GatewayUpdateProducerGke.  # noqa: E501

        Producer name  # noqa: E501

        :return: The name of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GatewayUpdateProducerGke.

        Producer name  # noqa: E501

        :param name: The name of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_name(self):
        """Gets the new_name of this GatewayUpdateProducerGke.  # noqa: E501

        Producer name  # noqa: E501

        :return: The new_name of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this GatewayUpdateProducerGke.

        Producer name  # noqa: E501

        :param new_name: The new_name of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def producer_encryption_key_name(self):
        """Gets the producer_encryption_key_name of this GatewayUpdateProducerGke.  # noqa: E501

        Dynamic producer encryption key  # noqa: E501

        :return: The producer_encryption_key_name of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._producer_encryption_key_name

    @producer_encryption_key_name.setter
    def producer_encryption_key_name(self, producer_encryption_key_name):
        """Sets the producer_encryption_key_name of this GatewayUpdateProducerGke.

        Dynamic producer encryption key  # noqa: E501

        :param producer_encryption_key_name: The producer_encryption_key_name of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """

        self._producer_encryption_key_name = producer_encryption_key_name

    @property
    def secure_access_allow_port_forwading(self):
        """Gets the secure_access_allow_port_forwading of this GatewayUpdateProducerGke.  # noqa: E501


        :return: The secure_access_allow_port_forwading of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_allow_port_forwading

    @secure_access_allow_port_forwading.setter
    def secure_access_allow_port_forwading(self, secure_access_allow_port_forwading):
        """Sets the secure_access_allow_port_forwading of this GatewayUpdateProducerGke.


        :param secure_access_allow_port_forwading: The secure_access_allow_port_forwading of this GatewayUpdateProducerGke.  # noqa: E501
        :type: bool
        """

        self._secure_access_allow_port_forwading = secure_access_allow_port_forwading

    @property
    def secure_access_bastion_issuer(self):
        """Gets the secure_access_bastion_issuer of this GatewayUpdateProducerGke.  # noqa: E501


        :return: The secure_access_bastion_issuer of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_bastion_issuer

    @secure_access_bastion_issuer.setter
    def secure_access_bastion_issuer(self, secure_access_bastion_issuer):
        """Sets the secure_access_bastion_issuer of this GatewayUpdateProducerGke.


        :param secure_access_bastion_issuer: The secure_access_bastion_issuer of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """

        self._secure_access_bastion_issuer = secure_access_bastion_issuer

    @property
    def secure_access_cluster_endpoint(self):
        """Gets the secure_access_cluster_endpoint of this GatewayUpdateProducerGke.  # noqa: E501


        :return: The secure_access_cluster_endpoint of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_cluster_endpoint

    @secure_access_cluster_endpoint.setter
    def secure_access_cluster_endpoint(self, secure_access_cluster_endpoint):
        """Sets the secure_access_cluster_endpoint of this GatewayUpdateProducerGke.


        :param secure_access_cluster_endpoint: The secure_access_cluster_endpoint of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """

        self._secure_access_cluster_endpoint = secure_access_cluster_endpoint

    @property
    def secure_access_enable(self):
        """Gets the secure_access_enable of this GatewayUpdateProducerGke.  # noqa: E501


        :return: The secure_access_enable of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_enable

    @secure_access_enable.setter
    def secure_access_enable(self, secure_access_enable):
        """Sets the secure_access_enable of this GatewayUpdateProducerGke.


        :param secure_access_enable: The secure_access_enable of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """

        self._secure_access_enable = secure_access_enable

    @property
    def secure_access_web(self):
        """Gets the secure_access_web of this GatewayUpdateProducerGke.  # noqa: E501


        :return: The secure_access_web of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_web

    @secure_access_web.setter
    def secure_access_web(self, secure_access_web):
        """Sets the secure_access_web of this GatewayUpdateProducerGke.


        :param secure_access_web: The secure_access_web of this GatewayUpdateProducerGke.  # noqa: E501
        :type: bool
        """

        self._secure_access_web = secure_access_web

    @property
    def tags(self):
        """Gets the tags of this GatewayUpdateProducerGke.  # noqa: E501

        List of the tags attached to this secret  # noqa: E501

        :return: The tags of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this GatewayUpdateProducerGke.

        List of the tags attached to this secret  # noqa: E501

        :param tags: The tags of this GatewayUpdateProducerGke.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def target_name(self):
        """Gets the target_name of this GatewayUpdateProducerGke.  # noqa: E501

        Target name  # noqa: E501

        :return: The target_name of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._target_name

    @target_name.setter
    def target_name(self, target_name):
        """Sets the target_name of this GatewayUpdateProducerGke.

        Target name  # noqa: E501

        :param target_name: The target_name of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """

        self._target_name = target_name

    @property
    def token(self):
        """Gets the token of this GatewayUpdateProducerGke.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GatewayUpdateProducerGke.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this GatewayUpdateProducerGke.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GatewayUpdateProducerGke.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def user_ttl(self):
        """Gets the user_ttl of this GatewayUpdateProducerGke.  # noqa: E501

        User TTL  # noqa: E501

        :return: The user_ttl of this GatewayUpdateProducerGke.  # noqa: E501
        :rtype: str
        """
        return self._user_ttl

    @user_ttl.setter
    def user_ttl(self, user_ttl):
        """Sets the user_ttl of this GatewayUpdateProducerGke.

        User TTL  # noqa: E501

        :param user_ttl: The user_ttl of this GatewayUpdateProducerGke.  # noqa: E501
        :type: str
        """

        self._user_ttl = user_ttl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayUpdateProducerGke):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayUpdateProducerGke):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class ItemGeneralInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cert_issue_details': 'CertificateIssueInfo',
        'certificate_chain_info': 'CertificateChainInfo',
        'classic_key_details': 'ClassicKeyDetailsInfo',
        'cluster_gw_url': 'str',
        'display_metadata': 'str',
        'dynamic_secret_producer_details': 'DynamicSecretProducerInfo',
        'password_policy': 'PasswordPolicyInfo',
        'rotated_secret_details': 'RotatedSecretDetailsInfo',
        'secure_remote_access_details': 'SecureRemoteAccess',
        'static_secret_info': 'StaticSecretDetailsInfo',
        'tokenizer_info': 'TokenizerInfo'
    }

    attribute_map = {
        'cert_issue_details': 'cert_issue_details',
        'certificate_chain_info': 'certificate_chain_info',
        'classic_key_details': 'classic_key_details',
        'cluster_gw_url': 'cluster_gw_url',
        'display_metadata': 'display_metadata',
        'dynamic_secret_producer_details': 'dynamic_secret_producer_details',
        'password_policy': 'password_policy',
        'rotated_secret_details': 'rotated_secret_details',
        'secure_remote_access_details': 'secure_remote_access_details',
        'static_secret_info': 'static_secret_info',
        'tokenizer_info': 'tokenizer_info'
    }

    def __init__(self, cert_issue_details=None, certificate_chain_info=None, classic_key_details=None, cluster_gw_url=None, display_metadata=None, dynamic_secret_producer_details=None, password_policy=None, rotated_secret_details=None, secure_remote_access_details=None, static_secret_info=None, tokenizer_info=None, local_vars_configuration=None):  # noqa: E501
        """ItemGeneralInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cert_issue_details = None
        self._certificate_chain_info = None
        self._classic_key_details = None
        self._cluster_gw_url = None
        self._display_metadata = None
        self._dynamic_secret_producer_details = None
        self._password_policy = None
        self._rotated_secret_details = None
        self._secure_remote_access_details = None
        self._static_secret_info = None
        self._tokenizer_info = None
        self.discriminator = None

        if cert_issue_details is not None:
            self.cert_issue_details = cert_issue_details
        if certificate_chain_info is not None:
            self.certificate_chain_info = certificate_chain_info
        if classic_key_details is not None:
            self.classic_key_details = classic_key_details
        if cluster_gw_url is not None:
            self.cluster_gw_url = cluster_gw_url
        if display_metadata is not None:
            self.display_metadata = display_metadata
        if dynamic_secret_producer_details is not None:
            self.dynamic_secret_producer_details = dynamic_secret_producer_details
        if password_policy is not None:
            self.password_policy = password_policy
        if rotated_secret_details is not None:
            self.rotated_secret_details = rotated_secret_details
        if secure_remote_access_details is not None:
            self.secure_remote_access_details = secure_remote_access_details
        if static_secret_info is not None:
            self.static_secret_info = static_secret_info
        if tokenizer_info is not None:
            self.tokenizer_info = tokenizer_info

    @property
    def cert_issue_details(self):
        """Gets the cert_issue_details of this ItemGeneralInfo.  # noqa: E501


        :return: The cert_issue_details of this ItemGeneralInfo.  # noqa: E501
        :rtype: CertificateIssueInfo
        """
        return self._cert_issue_details

    @cert_issue_details.setter
    def cert_issue_details(self, cert_issue_details):
        """Sets the cert_issue_details of this ItemGeneralInfo.


        :param cert_issue_details: The cert_issue_details of this ItemGeneralInfo.  # noqa: E501
        :type: CertificateIssueInfo
        """

        self._cert_issue_details = cert_issue_details

    @property
    def certificate_chain_info(self):
        """Gets the certificate_chain_info of this ItemGeneralInfo.  # noqa: E501


        :return: The certificate_chain_info of this ItemGeneralInfo.  # noqa: E501
        :rtype: CertificateChainInfo
        """
        return self._certificate_chain_info

    @certificate_chain_info.setter
    def certificate_chain_info(self, certificate_chain_info):
        """Sets the certificate_chain_info of this ItemGeneralInfo.


        :param certificate_chain_info: The certificate_chain_info of this ItemGeneralInfo.  # noqa: E501
        :type: CertificateChainInfo
        """

        self._certificate_chain_info = certificate_chain_info

    @property
    def classic_key_details(self):
        """Gets the classic_key_details of this ItemGeneralInfo.  # noqa: E501


        :return: The classic_key_details of this ItemGeneralInfo.  # noqa: E501
        :rtype: ClassicKeyDetailsInfo
        """
        return self._classic_key_details

    @classic_key_details.setter
    def classic_key_details(self, classic_key_details):
        """Sets the classic_key_details of this ItemGeneralInfo.


        :param classic_key_details: The classic_key_details of this ItemGeneralInfo.  # noqa: E501
        :type: ClassicKeyDetailsInfo
        """

        self._classic_key_details = classic_key_details

    @property
    def cluster_gw_url(self):
        """Gets the cluster_gw_url of this ItemGeneralInfo.  # noqa: E501


        :return: The cluster_gw_url of this ItemGeneralInfo.  # noqa: E501
        :rtype: str
        """
        return self._cluster_gw_url

    @cluster_gw_url.setter
    def cluster_gw_url(self, cluster_gw_url):
        """Sets the cluster_gw_url of this ItemGeneralInfo.


        :param cluster_gw_url: The cluster_gw_url of this ItemGeneralInfo.  # noqa: E501
        :type: str
        """

        self._cluster_gw_url = cluster_gw_url

    @property
    def display_metadata(self):
        """Gets the display_metadata of this ItemGeneralInfo.  # noqa: E501


        :return: The display_metadata of this ItemGeneralInfo.  # noqa: E501
        :rtype: str
        """
        return self._display_metadata

    @display_metadata.setter
    def display_metadata(self, display_metadata):
        """Sets the display_metadata of this ItemGeneralInfo.


        :param display_metadata: The display_metadata of this ItemGeneralInfo.  # noqa: E501
        :type: str
        """

        self._display_metadata = display_metadata

    @property
    def dynamic_secret_producer_details(self):
        """Gets the dynamic_secret_producer_details of this ItemGeneralInfo.  # noqa: E501


        :return: The dynamic_secret_producer_details of this ItemGeneralInfo.  # noqa: E501
        :rtype: DynamicSecretProducerInfo
        """
        return self._dynamic_secret_producer_details

    @dynamic_secret_producer_details.setter
    def dynamic_secret_producer_details(self, dynamic_secret_producer_details):
        """Sets the dynamic_secret_producer_details of this ItemGeneralInfo.


        :param dynamic_secret_producer_details: The dynamic_secret_producer_details of this ItemGeneralInfo.  # noqa: E501
        :type: DynamicSecretProducerInfo
        """

        self._dynamic_secret_producer_details = dynamic_secret_producer_details

    @property
    def password_policy(self):
        """Gets the password_policy of this ItemGeneralInfo.  # noqa: E501


        :return: The password_policy of this ItemGeneralInfo.  # noqa: E501
        :rtype: PasswordPolicyInfo
        """
        return self._password_policy

    @password_policy.setter
    def password_policy(self, password_policy):
        """Sets the password_policy of this ItemGeneralInfo.


        :param password_policy: The password_policy of this ItemGeneralInfo.  # noqa: E501
        :type: PasswordPolicyInfo
        """

        self._password_policy = password_policy

    @property
    def rotated_secret_details(self):
        """Gets the rotated_secret_details of this ItemGeneralInfo.  # noqa: E501


        :return: The rotated_secret_details of this ItemGeneralInfo.  # noqa: E501
        :rtype: RotatedSecretDetailsInfo
        """
        return self._rotated_secret_details

    @rotated_secret_details.setter
    def rotated_secret_details(self, rotated_secret_details):
        """Sets the rotated_secret_details of this ItemGeneralInfo.


        :param rotated_secret_details: The rotated_secret_details of this ItemGeneralInfo.  # noqa: E501
        :type: RotatedSecretDetailsInfo
        """

        self._rotated_secret_details = rotated_secret_details

    @property
    def secure_remote_access_details(self):
        """Gets the secure_remote_access_details of this ItemGeneralInfo.  # noqa: E501


        :return: The secure_remote_access_details of this ItemGeneralInfo.  # noqa: E501
        :rtype: SecureRemoteAccess
        """
        return self._secure_remote_access_details

    @secure_remote_access_details.setter
    def secure_remote_access_details(self, secure_remote_access_details):
        """Sets the secure_remote_access_details of this ItemGeneralInfo.


        :param secure_remote_access_details: The secure_remote_access_details of this ItemGeneralInfo.  # noqa: E501
        :type: SecureRemoteAccess
        """

        self._secure_remote_access_details = secure_remote_access_details

    @property
    def static_secret_info(self):
        """Gets the static_secret_info of this ItemGeneralInfo.  # noqa: E501


        :return: The static_secret_info of this ItemGeneralInfo.  # noqa: E501
        :rtype: StaticSecretDetailsInfo
        """
        return self._static_secret_info

    @static_secret_info.setter
    def static_secret_info(self, static_secret_info):
        """Sets the static_secret_info of this ItemGeneralInfo.


        :param static_secret_info: The static_secret_info of this ItemGeneralInfo.  # noqa: E501
        :type: StaticSecretDetailsInfo
        """

        self._static_secret_info = static_secret_info

    @property
    def tokenizer_info(self):
        """Gets the tokenizer_info of this ItemGeneralInfo.  # noqa: E501


        :return: The tokenizer_info of this ItemGeneralInfo.  # noqa: E501
        :rtype: TokenizerInfo
        """
        return self._tokenizer_info

    @tokenizer_info.setter
    def tokenizer_info(self, tokenizer_info):
        """Sets the tokenizer_info of this ItemGeneralInfo.


        :param tokenizer_info: The tokenizer_info of this ItemGeneralInfo.  # noqa: E501
        :type: TokenizerInfo
        """

        self._tokenizer_info = tokenizer_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemGeneralInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemGeneralInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.gateway_delete_allowed_management_access import GatewayDeleteAllowedManagementAccess  # noqa: E501
from akeyless.rest import ApiException

class TestGatewayDeleteAllowedManagementAccess(unittest.TestCase):
    """GatewayDeleteAllowedManagementAccess unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GatewayDeleteAllowedManagementAccess
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.gateway_delete_allowed_management_access.GatewayDeleteAllowedManagementAccess()  # noqa: E501
        if include_optional :
            return GatewayDeleteAllowedManagementAccess(
                gateway_url = 'http://localhost:8000', 
                password = '0', 
                sub_admin_id = '0', 
                token = '0', 
                uid_token = '0', 
                username = '0'
            )
        else :
            return GatewayDeleteAllowedManagementAccess(
                sub_admin_id = '0',
        )

    def testGatewayDeleteAllowedManagementAccess(self):
        """Test GatewayDeleteAllowedManagementAccess"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class Producer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'active': 'bool',
        'failure_message': 'str',
        'id': 'int',
        'init': 'bool',
        'name': 'str',
        'type': 'str'
    }

    attribute_map = {
        'active': 'active',
        'failure_message': 'failure_message',
        'id': 'id',
        'init': 'init',
        'name': 'name',
        'type': 'type'
    }

    def __init__(self, active=None, failure_message=None, id=None, init=None, name=None, type=None, local_vars_configuration=None):  # noqa: E501
        """Producer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._active = None
        self._failure_message = None
        self._id = None
        self._init = None
        self._name = None
        self._type = None
        self.discriminator = None

        if active is not None:
            self.active = active
        if failure_message is not None:
            self.failure_message = failure_message
        if id is not None:
            self.id = id
        if init is not None:
            self.init = init
        if name is not None:
            self.name = name
        if type is not None:
            self.type = type

    @property
    def active(self):
        """Gets the active of this Producer.  # noqa: E501


        :return: The active of this Producer.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this Producer.


        :param active: The active of this Producer.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def failure_message(self):
        """Gets the failure_message of this Producer.  # noqa: E501


        :return: The failure_message of this Producer.  # noqa: E501
        :rtype: str
        """
        return self._failure_message

    @failure_message.setter
    def failure_message(self, failure_message):
        """Sets the failure_message of this Producer.


        :param failure_message: The failure_message of this Producer.  # noqa: E501
        :type: str
        """

        self._failure_message = failure_message

    @property
    def id(self):
        """Gets the id of this Producer.  # noqa: E501


        :return: The id of this Producer.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Producer.


        :param id: The id of this Producer.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def init(self):
        """Gets the init of this Producer.  # noqa: E501


        :return: The init of this Producer.  # noqa: E501
        :rtype: bool
        """
        return self._init

    @init.setter
    def init(self, init):
        """Sets the init of this Producer.


        :param init: The init of this Producer.  # noqa: E501
        :type: bool
        """

        self._init = init

    @property
    def name(self):
        """Gets the name of this Producer.  # noqa: E501


        :return: The name of this Producer.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Producer.


        :param name: The name of this Producer.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """Gets the type of this Producer.  # noqa: E501


        :return: The type of this Producer.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Producer.


        :param type: The type of this Producer.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Producer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Producer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class ElasticsearchLogForwardingConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'elasticsearch_api_key': 'str',
        'elasticsearch_auth_type': 'str',
        'elasticsearch_cloud_id': 'str',
        'elasticsearch_index': 'str',
        'elasticsearch_nodes': 'str',
        'elasticsearch_password': 'str',
        'elasticsearch_server_type': 'str',
        'elasticsearch_user_name': 'str'
    }

    attribute_map = {
        'elasticsearch_api_key': 'elasticsearch_api_key',
        'elasticsearch_auth_type': 'elasticsearch_auth_type',
        'elasticsearch_cloud_id': 'elasticsearch_cloud_id',
        'elasticsearch_index': 'elasticsearch_index',
        'elasticsearch_nodes': 'elasticsearch_nodes',
        'elasticsearch_password': 'elasticsearch_password',
        'elasticsearch_server_type': 'elasticsearch_server_type',
        'elasticsearch_user_name': 'elasticsearch_user_name'
    }

    def __init__(self, elasticsearch_api_key=None, elasticsearch_auth_type=None, elasticsearch_cloud_id=None, elasticsearch_index=None, elasticsearch_nodes=None, elasticsearch_password=None, elasticsearch_server_type=None, elasticsearch_user_name=None, local_vars_configuration=None):  # noqa: E501
        """ElasticsearchLogForwardingConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._elasticsearch_api_key = None
        self._elasticsearch_auth_type = None
        self._elasticsearch_cloud_id = None
        self._elasticsearch_index = None
        self._elasticsearch_nodes = None
        self._elasticsearch_password = None
        self._elasticsearch_server_type = None
        self._elasticsearch_user_name = None
        self.discriminator = None

        if elasticsearch_api_key is not None:
            self.elasticsearch_api_key = elasticsearch_api_key
        if elasticsearch_auth_type is not None:
            self.elasticsearch_auth_type = elasticsearch_auth_type
        if elasticsearch_cloud_id is not None:
            self.elasticsearch_cloud_id = elasticsearch_cloud_id
        if elasticsearch_index is not None:
            self.elasticsearch_index = elasticsearch_index
        if elasticsearch_nodes is not None:
            self.elasticsearch_nodes = elasticsearch_nodes
        if elasticsearch_password is not None:
            self.elasticsearch_password = elasticsearch_password
        if elasticsearch_server_type is not None:
            self.elasticsearch_server_type = elasticsearch_server_type
        if elasticsearch_user_name is not None:
            self.elasticsearch_user_name = elasticsearch_user_name

    @property
    def elasticsearch_api_key(self):
        """Gets the elasticsearch_api_key of this ElasticsearchLogForwardingConfig.  # noqa: E501


        :return: The elasticsearch_api_key of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :rtype: str
        """
        return self._elasticsearch_api_key

    @elasticsearch_api_key.setter
    def elasticsearch_api_key(self, elasticsearch_api_key):
        """Sets the elasticsearch_api_key of this ElasticsearchLogForwardingConfig.


        :param elasticsearch_api_key: The elasticsearch_api_key of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :type: str
        """

        self._elasticsearch_api_key = elasticsearch_api_key

    @property
    def elasticsearch_auth_type(self):
        """Gets the elasticsearch_auth_type of this ElasticsearchLogForwardingConfig.  # noqa: E501


        :return: The elasticsearch_auth_type of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :rtype: str
        """
        return self._elasticsearch_auth_type

    @elasticsearch_auth_type.setter
    def elasticsearch_auth_type(self, elasticsearch_auth_type):
        """Sets the elasticsearch_auth_type of this ElasticsearchLogForwardingConfig.


        :param elasticsearch_auth_type: The elasticsearch_auth_type of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :type: str
        """

        self._elasticsearch_auth_type = elasticsearch_auth_type

    @property
    def elasticsearch_cloud_id(self):
        """Gets the elasticsearch_cloud_id of this ElasticsearchLogForwardingConfig.  # noqa: E501


        :return: The elasticsearch_cloud_id of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :rtype: str
        """
        return self._elasticsearch_cloud_id

    @elasticsearch_cloud_id.setter
    def elasticsearch_cloud_id(self, elasticsearch_cloud_id):
        """Sets the elasticsearch_cloud_id of this ElasticsearchLogForwardingConfig.


        :param elasticsearch_cloud_id: The elasticsearch_cloud_id of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :type: str
        """

        self._elasticsearch_cloud_id = elasticsearch_cloud_id

    @property
    def elasticsearch_index(self):
        """Gets the elasticsearch_index of this ElasticsearchLogForwardingConfig.  # noqa: E501


        :return: The elasticsearch_index of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :rtype: str
        """
        return self._elasticsearch_index

    @elasticsearch_index.setter
    def elasticsearch_index(self, elasticsearch_index):
        """Sets the elasticsearch_index of this ElasticsearchLogForwardingConfig.


        :param elasticsearch_index: The elasticsearch_index of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :type: str
        """

        self._elasticsearch_index = elasticsearch_index

    @property
    def elasticsearch_nodes(self):
        """Gets the elasticsearch_nodes of this ElasticsearchLogForwardingConfig.  # noqa: E501


        :return: The elasticsearch_nodes of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :rtype: str
        """
        return self._elasticsearch_nodes

    @elasticsearch_nodes.setter
    def elasticsearch_nodes(self, elasticsearch_nodes):
        """Sets the elasticsearch_nodes of this ElasticsearchLogForwardingConfig.


        :param elasticsearch_nodes: The elasticsearch_nodes of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :type: str
        """

        self._elasticsearch_nodes = elasticsearch_nodes

    @property
    def elasticsearch_password(self):
        """Gets the elasticsearch_password of this ElasticsearchLogForwardingConfig.  # noqa: E501


        :return: The elasticsearch_password of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :rtype: str
        """
        return self._elasticsearch_password

    @elasticsearch_password.setter
    def elasticsearch_password(self, elasticsearch_password):
        """Sets the elasticsearch_password of this ElasticsearchLogForwardingConfig.


        :param elasticsearch_password: The elasticsearch_password of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :type: str
        """

        self._elasticsearch_password = elasticsearch_password

    @property
    def elasticsearch_server_type(self):
        """Gets the elasticsearch_server_type of this ElasticsearchLogForwardingConfig.  # noqa: E501


        :return: The elasticsearch_server_type of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :rtype: str
        """
        return self._elasticsearch_server_type

    @elasticsearch_server_type.setter
    def elasticsearch_server_type(self, elasticsearch_server_type):
        """Sets the elasticsearch_server_type of this ElasticsearchLogForwardingConfig.


        :param elasticsearch_server_type: The elasticsearch_server_type of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :type: str
        """

        self._elasticsearch_server_type = elasticsearch_server_type

    @property
    def elasticsearch_user_name(self):
        """Gets the elasticsearch_user_name of this ElasticsearchLogForwardingConfig.  # noqa: E501


        :return: The elasticsearch_user_name of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :rtype: str
        """
        return self._elasticsearch_user_name

    @elasticsearch_user_name.setter
    def elasticsearch_user_name(self, elasticsearch_user_name):
        """Sets the elasticsearch_user_name of this ElasticsearchLogForwardingConfig.


        :param elasticsearch_user_name: The elasticsearch_user_name of this ElasticsearchLogForwardingConfig.  # noqa: E501
        :type: str
        """

        self._elasticsearch_user_name = elasticsearch_user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ElasticsearchLogForwardingConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ElasticsearchLogForwardingConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class HuaweiAccessRules(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'auth_endpoint': 'str',
        'domain_id': 'list[str]',
        'domain_name': 'list[str]',
        'tenant_id': 'list[str]',
        'tenant_name': 'list[str]',
        'user_id': 'list[str]',
        'user_name': 'list[str]'
    }

    attribute_map = {
        'auth_endpoint': 'auth_endpoint',
        'domain_id': 'domain_id',
        'domain_name': 'domain_name',
        'tenant_id': 'tenant_id',
        'tenant_name': 'tenant_name',
        'user_id': 'user_id',
        'user_name': 'user_name'
    }

    def __init__(self, auth_endpoint=None, domain_id=None, domain_name=None, tenant_id=None, tenant_name=None, user_id=None, user_name=None, local_vars_configuration=None):  # noqa: E501
        """HuaweiAccessRules - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._auth_endpoint = None
        self._domain_id = None
        self._domain_name = None
        self._tenant_id = None
        self._tenant_name = None
        self._user_id = None
        self._user_name = None
        self.discriminator = None

        if auth_endpoint is not None:
            self.auth_endpoint = auth_endpoint
        if domain_id is not None:
            self.domain_id = domain_id
        if domain_name is not None:
            self.domain_name = domain_name
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if tenant_name is not None:
            self.tenant_name = tenant_name
        if user_id is not None:
            self.user_id = user_id
        if user_name is not None:
            self.user_name = user_name

    @property
    def auth_endpoint(self):
        """Gets the auth_endpoint of this HuaweiAccessRules.  # noqa: E501

        The auth URL.  # noqa: E501

        :return: The auth_endpoint of this HuaweiAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._auth_endpoint

    @auth_endpoint.setter
    def auth_endpoint(self, auth_endpoint):
        """Sets the auth_endpoint of this HuaweiAccessRules.

        The auth URL.  # noqa: E501

        :param auth_endpoint: The auth_endpoint of this HuaweiAccessRules.  # noqa: E501
        :type: str
        """

        self._auth_endpoint = auth_endpoint

    @property
    def domain_id(self):
        """Gets the domain_id of this HuaweiAccessRules.  # noqa: E501

        The list of domain ids that the login is restricted to.  # noqa: E501

        :return: The domain_id of this HuaweiAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this HuaweiAccessRules.

        The list of domain ids that the login is restricted to.  # noqa: E501

        :param domain_id: The domain_id of this HuaweiAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._domain_id = domain_id

    @property
    def domain_name(self):
        """Gets the domain_name of this HuaweiAccessRules.  # noqa: E501

        The list of domainNames that the login is restricted to.  # noqa: E501

        :return: The domain_name of this HuaweiAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        """Sets the domain_name of this HuaweiAccessRules.

        The list of domainNames that the login is restricted to.  # noqa: E501

        :param domain_name: The domain_name of this HuaweiAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._domain_name = domain_name

    @property
    def tenant_id(self):
        """Gets the tenant_id of this HuaweiAccessRules.  # noqa: E501

        The list of tenantIDs  that the login is restricted to.  # noqa: E501

        :return: The tenant_id of this HuaweiAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this HuaweiAccessRules.

        The list of tenantIDs  that the login is restricted to.  # noqa: E501

        :param tenant_id: The tenant_id of this HuaweiAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._tenant_id = tenant_id

    @property
    def tenant_name(self):
        """Gets the tenant_name of this HuaweiAccessRules.  # noqa: E501

        The list of tenantNames  that the login is restricted to.  # noqa: E501

        :return: The tenant_name of this HuaweiAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._tenant_name

    @tenant_name.setter
    def tenant_name(self, tenant_name):
        """Sets the tenant_name of this HuaweiAccessRules.

        The list of tenantNames  that the login is restricted to.  # noqa: E501

        :param tenant_name: The tenant_name of this HuaweiAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._tenant_name = tenant_name

    @property
    def user_id(self):
        """Gets the user_id of this HuaweiAccessRules.  # noqa: E501

        The list of user ids that the login is restricted to.  # noqa: E501

        :return: The user_id of this HuaweiAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this HuaweiAccessRules.

        The list of user ids that the login is restricted to.  # noqa: E501

        :param user_id: The user_id of this HuaweiAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._user_id = user_id

    @property
    def user_name(self):
        """Gets the user_name of this HuaweiAccessRules.  # noqa: E501

        The list of user names that the login is restricted to.  # noqa: E501

        :return: The user_name of this HuaweiAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this HuaweiAccessRules.

        The list of user names that the login is restricted to.  # noqa: E501

        :param user_name: The user_name of this HuaweiAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HuaweiAccessRules):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HuaweiAccessRules):
            return True

        return self.to_dict() != other.to_dict()
